@@ -1,5 +1,5 @@
 ftp_base_url <- function() {
-  'http://ftp.ebi.ac.uk/pub/databases/genenames/hgnc/'
+  'https://ftp.ebi.ac.uk/pub/databases/genenames/hgnc/'
 }
 
 ftp_archive <- function() {
